% This m-file if part of an m-script collection with the aim
% to prove or disprove the claims of Dr. Randell Mills in his grand unified theory
% of classical physics (GUTCP)
% http://brilliantlightpower.com/book-download-and-streaming/

clear % delete all variables from the workspace
% ######### control the script behavior ##############
format long;

% ######### physical constants #######################

mu_0 = 4*pi*10^-7;         % Vacuum permeability in [N/A^2]
c_0 = 299792458;           % speed of light in vacuum  [m/s]
ec = 1.6021766208*10^-19;  % elementary charge [C]
h = 6.626070040*10^-34;    % plank constant [J*s]
h_bar = 1.0545718 *10^-34; % reduced plank constant [J*s]
eps_0 = 1/(mu_0*c_0^2);    % Vacuum permittivity in [F/m]
m_e = 9.10938356*10^-31;   % mass of the electron [kg]
m_p = 1.672621898*10^-27;  % mass of the proton [kg]
alpha = (mu_0*ec^2*c_0)/(2*h); % fine structure constant []
a_0 = 5.2917721067*10^-11;    % Bohr radius [m]
mu_b = 9.274009994*10^-24;    % Bohr magneton [J/T]

% ######### ionization energies for some one-electron atoms #####################

% formular for all atoms with just 1 electron -> loop over first 34 atoms
% corresponding values from Mills on p.122 Table 1.5.
disp(['##### Ionization energies of one electron atoms #####'])
for index=1:34
  
  Z=index; % number of protons of the atoms
  if(index==1) % special case hydrogen has only a proton and no neutron
    A=1; % mass number of H - 1 proton no neutron
  else
    A=2*Z; % normal case: same number of neutrons and protons
  end
  % p.120 (1.293)
  term1=((alpha*Z)^2*m_e*c_0^2)/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2)+m_e/(m_p*A));
  term2=m_e*c_0^2*(1/(sqrt(1-((alpha*Z)/(1+m_e/(2*m_p*A)))^2))-1);
  e_ion=term1-term2;
  e_ion_eV = e_ion/ec;

  disp(['Atom with ',num2str(index),' protons: ',num2str(e_ion_eV),'eV.'])
end
max_dev_mills_me = abs((15977.86-e_ion_eV)/15977.86)*100;
disp(['Results:'])
disp(['For experimental values go to: https://en.wikipedia.org/wiki/Ionization_energies_of_the_elements_(data_page)#WEL'])
disp(['- I get nearly the same results as Mills - max. relative error between Mills and me is ',num2str(max_dev_mills_me),'% for 34 protons.'])
disp(['- The agreement between Mills equation and the experimental values are remarkable and exactly as he claims on p.122'])
disp(['- No fitting parameter used - just fundamental constants'])
disp(['- Mills gave all the experimental values in the table on p.122 - no value was different than wiki source (no manipulation of a single digit)'])
disp(['- Standard QM can only compute these values with factors and fitted values. See here:'])
disp(['https://en.wikipedia.org/wiki/Computational_chemistry'])
disp(['https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3671562/'])
disp(['https://socratic.org/questions/how-to-calculate-the-first-and-second-ionization-energies-of-helium'])


% ######### ionization energies for some four-electron atoms #####################

disp([''])
disp([''])
disp([''])
disp(['##### Ionization energies of four electron atoms #####'])
for index=5:29
  
  Z=index; % number of protons of the atoms
  
  % GUTCP p.315 (10.51)
  r1 = a_0*(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
  % r1 in units of a_0 (as is used in GUTCP formulars)
  r1_a_0=(1/(Z-1)-(sqrt(3/4))/(Z*(Z-1)));
  r2=r1;
  % GUTCP p.316 (10.62)
  % long term split in 3 parts
  r4_p1=(a_0*(1-(sqrt(3/4))/(Z)))/((Z-3)-(1/4-1/Z)*(sqrt(3/4))/(r1_a_0));
  r4_p2=(1-(sqrt(3/4))/Z)^2/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0)^2;
  r4_p3=4*(((Z-3)/(Z-2))*r1_a_0*10*sqrt(3/4))/((Z-3)-(1/4-1/Z)*sqrt(3/4)/r1_a_0);
  r4=(r4_p1+a_0*sqrt(r4_p2+r4_p3))/2; % (+) chosen to get a positiv distance
  r4_a_0=r4/a_0;
  r3=r4;
  r3_a_0=r4_a_0;
  % (10.63)
  E_electric = ((Z-3)*ec^2)/(8*pi*eps_0*r4);
  E_electric_eV =  E_electric/ec;
  % (7.64)
  E_magnetic = (8*pi*mu_0*mu_b^2)/(r4^3);
  E_magnetic_eV = E_magnetic/ec;
  % (10.46)
  delta_v = (r1^2*h_bar)/(m_e*r4^3);
  % (10.47)
  delta_E_T = m_e*delta_v^2;
  delta_E_T_eV = delta_E_T/ec;
  % p.317 (10.67)
  E_ionization_eV = E_electric_eV-1/Z*E_magnetic_eV-delta_E_T_eV;
  
  disp(['Atom with ',num2str(index),' protons: ',num2str(E_ionization_eV),'eV.'])
end
max_dev_mills_me = abs((2446.7448-E_ionization_eV)/2446.7448)*100; % value for 34 protons
disp(['Results:'])
disp(['For experimental values go to: https://en.wikipedia.org/wiki/Ionization_energies_of_the_elements_(data_page)#WEL'])
disp(['- I get nearly the same results as Mills - max. relative error between Mills and me is ',num2str(max_dev_mills_me),'% for 29 protons.'])
disp(['- The agreement between Mills equation and the experimental values are remarkable and exactly as he claims on p.318'])
disp(['- The comments of the one electron atoms apply also in the case of the four electron atom.'])
disp(['']);
disp(['']);
%disp(['- Mills gave all the experimental values in the table on p.122 - no value was different than wiki source (no manipulation of a single digit)'])
%disp(['- Standard QM can only compute these values with factors and fitted values. See here:'])
%disp(['https://en.wikipedia.org/wiki/Computational_chemistry'])
%disp(['https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3671562/'])
%disp(['https://socratic.org/questions/how-to-calculate-the-first-and-second-ionization-energies-of-helium'])
